@@ -4,6 +4,8 @@
 #' quality assessment databases publicly available at
 #' \href{https://universalfqa.org/}{universalfqa.org}.
 #'
+#' @param timeout Number of seconds to query UniversalFQA before timing out.
+#'
 #' @return A data frame with 4 columns:
 #' \itemize{
 #'   \item database_id (numeric)
@@ -20,9 +22,9 @@
 #' @export
 
 
-index_fqa_databases <- function() {
+index_fqa_databases <- function(timeout = 5) {
 
-  out <- index_fqa_databases_internal()
+  out <- index_fqa_databases_internal(timeout)
 
   if (nrow(out) == 0){
     memoise::forget(index_fqa_databases_internal)
