@@ -9,36 +9,26 @@
 
 
 is_transect_list <- function(possible_list) {
-  return <- TRUE
 
-  if (is.null(possible_list)) {
-    return <- FALSE
-  }
+  return <- FALSE
 
   tryCatch({
-    if (length(possible_list) == 0) {
-      return <- FALSE
-    }
 
-    if (!is.data.frame(possible_list[[1]])) {
-      return <- FALSE
-    }
-
-    if (ncol(possible_list[[1]]) != 14) {
-      return <- FALSE
-    }
-
-    if (colnames(possible_list[[1]][1]) != "V1") {
-      return <- FALSE
-    }
-
-    if (!("Species Richness:" %in% possible_list[[1]]$V1)) {
-      return <- FALSE
+    if (is.list(eval(possible_list)) & (length(possible_list) != 0)) {
+      outcomes <- lapply(possible_list,
+                         is_transect) |>
+        as.logical()
+      return <- all(outcomes) & (sum(outcomes) >= 1)
     }
 
   },
+
   error = function(e) {
     return <- FALSE
+  },
+
+  warning = function(w){
+    return <- FALSE
   })
 
   return
