@@ -1,8 +1,9 @@
 test_that("index_fqa_databases_internal works", {
 
-  expect_error(index_fqa_databases_internal("hi"))
+  expect_error(index_fqa_databases_internal("hi"),
+               "timeout must be an integer.")
 
-  databases <- suppressMessages(index_fqa_databases_internal())
+  databases <- suppressMessages(index_fqa_databases_internal(timeout = 10))
 
   expect_equal(ncol(databases), 4)
   expect_equal(names(databases), c("database_id", "region", "year", "description"))
