@@ -6,10 +6,9 @@ test_that("transect_list_inventory works",  {
   expect_message(transect_list_inventory(faithful))
   expect_true(is.list(suppressMessages(transect_list_inventory(faithful))))
 
-  skip_if_offline()
+  test_raw <- suppressMessages(download_transect(4492))
 
-  if (nrow(suppressMessages(download_transect(4492))) != 0){
-    test_raw <- download_transect(4492)
+  if (nrow(test_raw) != 0){
     test_transect_list <- list(test_raw,
                                test_raw,
                                test_raw)
@@ -18,8 +17,6 @@ test_that("transect_list_inventory works",  {
     expect_equal(class(inv_list), "list")
     expect_equal(length(inv_list), 3)
     expect_equal(ncol(inv_list[[1]]), 13)
-  } else {
-    expect_message(download_transect(4492))
   }
 
 })
