@@ -8,37 +8,27 @@ test_that("transect_phys works", {
   expect_equal(typeof(test[[2]]), "double")
   expect_equal(names(test)[2], "frequency")
 
-  if (nrow(suppressMessages(download_transect(4492))) != 0) {
-    test_raw <- download_transect(4492) # normal database
+  test_raw <- suppressMessages(download_transect(4492)) # normal database
+  if (nrow(test_raw) != 0) {
     test <- transect_phys(test_raw)
     expect_equal(ncol(test), 6)
     expect_equal(typeof(test[[2]]), "double")
     expect_equal(names(test)[2], "frequency")
-  } else {
-    # for when API is down
-    expect_message(download_transect(4492))
   }
 
-  if (nrow(suppressMessages(download_transect(7025))) != 0) {
-    test_raw <- download_transect(7025) # custom database
+  test_raw <- suppressMessages(download_transect(7025)) # custom database
+  if (nrow(test_raw) != 0) {
     test <- transect_phys(test_raw)
     expect_equal(ncol(test), 6)
     expect_equal(typeof(test[[2]]), "double")
     expect_equal(names(test)[2], "frequency")
-  } else {
-    # for when API is down
-    expect_message(download_transect(7025))
   }
 
-  if (nrow(suppressMessages(download_transect(6444))) != 0) {
-    test_raw <- download_transect(6444) # includes omernik
+  test_raw <- suppressMessages(download_transect(6444))  # includes omernik
+  if (nrow(test_raw) != 0) {
     test <- transect_phys(test_raw)
     expect_equal(ncol(test), 6)
     expect_equal(typeof(test[[2]]), "double")
     expect_equal(names(test)[2], "frequency")
-  } else {
-    # for when API is down
-    expect_message(download_transect(6444))
   }
-
 })
